// This extension was developed by :
// * Mark Bokil http://markbokil.com
// * http://markbokil.com/downloads/extensions/
// version: 1.0.1
// date: 9-2-12
// Licence: GPLv2+

const St = imports.gi.St;
const PanelMenu = imports.ui.panelMenu;
const PopupMenu = imports.ui.popupMenu;
const Util = imports.misc.util;
const Main = imports.ui.main;
const Lang = imports.lang;
const GLib = imports.gi.GLib;
const Shell = imports.gi.Shell;
const Gettext = imports.gettext;
const _ = Gettext.domain('extensionsshortcut').gettext;
const ExtensionsPath = GLib.build_filenamev([global.userdatadir, 'extensions/']);


// ExtensionsShortcut function
function ExtensionsShortcuts(metadata)
{	
	let locales = metadata.path + "/locale";
	Gettext.bindtextdomain('extentionsshortcuts', locales);

	this._init();
}

// Prototype
ExtensionsShortcuts.prototype =
{
	__proto__: PanelMenu.Button.prototype,
	
    	_init: function(gicon) 
    	{			
		PanelMenu.Button.prototype._init.call(this, St.Align.START);

		this._iconActor = new St.Icon({ icon_name: 'preferences-other-symbolic',
                                   		icon_type: St.IconType.SYMBOLIC,
                                        style_class: 'system-status-icon' });

        this.actor.add_actor(this._iconActor); 
		this._iconActor.get_parent().add_style_class_name("panelButtonWidth");
			
		this._buildMenu();
	},
	
	_buildMenu: function()
	{    			
		this.ie = new PopupMenu.PopupMenuItem("Installed Extensions");
		this.menu.addMenuItem(this.ie);
		this.ie.connect('activate', Lang.bind(this, this._gotoLocalExtensions));

		this.ae = new PopupMenu.PopupMenuItem("Browse Extensions");
		this.menu.addMenuItem(this.ae);
		this.ae.connect('activate', Lang.bind(this, this._gotoAllExtensions));

		this.pf = new PopupMenu.PopupMenuItem("Extension Preferences");
		this.menu.addMenuItem(this.pf);
		this.pf.connect('activate', Lang.bind(this, this._gotoExtensionPreferences));

		this.menu.addMenuItem(new PopupMenu.PopupSeparatorMenuItem());

		this.ef = new PopupMenu.PopupMenuItem("Open Extensions Folder");
		this.menu.addMenuItem(this.ef);
		this.ef.connect('activate', Lang.bind(this, this._gotoLocalFolder));

		this.rs = new PopupMenu.PopupMenuItem("Restart Shell");
		this.menu.addMenuItem(this.rs);
		this.rs.connect('activate', Lang.bind(this, this._restartShell));
	},

	_gotoLocalExtensions: function() {
		Main.Util.spawnCommandLine('xdg-open https://extensions.gnome.org/local/');
	},

	_gotoAllExtensions: function() {
		Main.Util.spawnCommandLine('xdg-open https://extensions.gnome.org/');
	},

	_gotoLocalFolder: function() {
		Main.Util.spawnCommandLine('xdg-open ' + ExtensionsPath);
	},

	_gotoExtensionPreferences: function() {
		Main.Util.spawnCommandLine('gnome-shell-extension-prefs');
	},

	_restartShell: function() {
		global.reexec_self();
	},


	enable: function()
	{
		Main.panel._rightBox.insert_child_at_index(this.actor, 0);
		Main.panel._menus.addMenu(this.menu);
	},

	disable: function()
	{
		Main.panel._menus.removeMenu(this.menu);
		Main.panel._rightBox.remove_actor(this.actor);
	}
}
	

// Init function
function init(metadata) 
{		
	return new ExtensionsShortcuts(metadata);
}
